# mm-balance

### Install on Ubuntu
```shell
apt update && apt-get install build-essential libgmp3-dev python3-dev -y

curl -LsSf https://astral.sh/uv/install.sh | sh
# Restart your shell or run: source $HOME/.cargo/env

uv tool install mm-balance

uv tool update-shell
# Restart your shell
```
